@@ -1,5 +1,5 @@
 /*
- * memory.c:  libxml memory allocator wrapper.
+ * xmlmemory.c:  libxml memory allocator wrapper.
  *
  * daniel@veillard.com
  */
@@ -11,19 +11,32 @@
 #ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
+
 #ifdef HAVE_TIME_H
 #include <time.h>
 #endif
+
+#ifdef HAVE_STDLIB_H
+#include <stdlib.h>
+#else
 #ifdef HAVE_MALLOC_H
 #include <malloc.h>
 #endif
-#ifdef HAVE_STDLIB_H
-#include <stdlib.h>
 #endif
+
 #ifdef HAVE_CTYPE_H
 #include <ctype.h>
 #endif
 
+/**
+ * MEM_LIST:
+ *
+ * keep track of all allocated blocks for error reporting 
+ * Always build the memory list !
+ */
+#ifndef MEM_LIST
+#define MEM_LIST /* keep a list of all the allocated memory blocks */
+#endif
 
 #include <libxml/xmlmemory.h>
 #include <libxml/globals.h>
@@ -31,7 +44,6 @@
 
 void xmlMallocBreakpoint(void);
 void * xmlMemMalloc(size_t size);
-void * xmlMallocLoc(size_t size, const char * file, int line);
 void * xmlMemRealloc(void *ptr,size_t size);
 void xmlMemFree(void *ptr);
 char * xmlMemoryStrdup(const char *str);
@@ -156,7 +168,7 @@ xmlMallocLoc(size_t size, const char * file, int line)
 
     if (!p) {
 	xmlGenericError(xmlGenericErrorContext,
-		"xmlMalloc : Out of free space\n");
+		"xmlMallocLoc : Out of free space\n");
 	xmlMemoryDump();
 	return(NULL);
     }   
@@ -333,20 +345,20 @@ xmlMemFree(void *ptr)
     
 error:    
     xmlGenericError(xmlGenericErrorContext,
-	    "xmlFree(%lX) error\n", (unsigned long) ptr);
+	    "xmlMemFree(%lX) error\n", (unsigned long) ptr);
     xmlMallocBreakpoint();
     return;
 }
 
 /**
  * xmlMemStrdupLoc:
- * @ptr:  the initial string pointer
+ * @str:  the initial string pointer
  * @file:  the file name or NULL
  * @line:  the line number
  *
  * a strdup() equivalent, with logging of the allocation info.
  *
- * Returns a pointer to the new string or NULL if allocation error occured.
+ * Returns a pointer to the new string or NULL if allocation error occurred.
  */
 
 char *
@@ -403,7 +415,7 @@ error:
  *
  * a strdup() equivalent, with logging of the allocation info.
  *
- * Returns a pointer to the new string or NULL if allocation error occured.
+ * Returns a pointer to the new string or NULL if allocation error occurred.
  */
 
 char *
@@ -414,7 +426,7 @@ xmlMemoryStrdup(const char *str) {
 /**
  * xmlMemUsed:
  *
- * returns the amount of memory currenly allocated
+ * returns the amount of memory currently allocated
  *
  * Returns an int representing the amount of memory allocated.
  */
@@ -446,7 +458,7 @@ xmlMemContentShow(FILE *fp, MEMHDR *p)
 
     for (i = 0;i < len;i++) {
         if (buf[i] == 0) break;
-	if (!isprint(buf[i])) break;
+	if (!isprint((unsigned char) buf[i])) break;
     }
     if ((i < 4) && ((buf[i] != 0) || (i == 0))) {
         if (len >= 4) {
@@ -506,7 +518,7 @@ xmlMemShow(FILE *fp, int nr)
 	fprintf(fp,"NUMBER   SIZE  TYPE   WHERE\n");
 	p = memlist;
 	while ((p) && nr > 0) {
-	      fprintf(fp,"%6lu %6u ",p->mh_number,p->mh_size);
+	      fprintf(fp,"%6lu %6lu ",p->mh_number,(unsigned long)p->mh_size);
 	    switch (p->mh_type) {
 	       case STRDUP_TYPE:fprintf(fp,"strdup()  in ");break;
 	       case MALLOC_TYPE:fprintf(fp,"malloc()  in ");break;
@@ -539,7 +551,7 @@ xmlMemDisplay(FILE *fp)
 {
 #ifdef MEM_LIST
     MEMHDR *p;
-    int     idx;
+    unsigned idx;
     int     nb = 0;
 #if defined(HAVE_LOCALTIME) && defined(HAVE_STRFTIME)
     time_t currentTime;
@@ -559,7 +571,8 @@ xmlMemDisplay(FILE *fp)
     idx = 0;
     p = memlist;
     while (p) {
-	  fprintf(fp,"%-5u  %6lu %6u ",idx++,p->mh_number,p->mh_size);
+	  fprintf(fp,"%-5u  %6lu %6lu ",idx++,p->mh_number,
+		  (unsigned long)p->mh_size);
         switch (p->mh_type) {
            case STRDUP_TYPE:fprintf(fp,"strdup()  in ");break;
            case MALLOC_TYPE:fprintf(fp,"malloc()  in ");break;
@@ -638,7 +651,6 @@ static FILE *xmlMemoryDumpFile = NULL;
 void
 xmlMemoryDump(void)
 {
-#if defined(DEBUG_MEMORY_LOCATION) | defined(DEBUG_MEMORY)
     FILE *dump;
 
     dump = fopen(".memdump", "w");
@@ -649,7 +661,6 @@ xmlMemoryDump(void)
     xmlMemDisplay(xmlMemoryDumpFile);
 
     if (dump != NULL) fclose(dump);
-#endif
 }
 
 
